@@ -1,4 +1,8 @@
-import 'whatwg-fetch';
+import { PageConfig, URLExt } from '@jupyterlab/coreutils';
+(window as any).__webpack_public_path__ = URLExt.join(
+  PageConfig.getBaseUrl(),
+  'static/gator/'
+);
 
 import { Gator } from './app/app';
 
@@ -7,7 +11,7 @@ import '../style/index.css';
 /**
  * The main function
  */
-async function main(): Promise<void> {
+export default async function main(): Promise<void> {
   const app = new Gator();
   const mods = [
     require('./plugins/paths'),
